@@ -6,7 +6,7 @@ use LibraryCheck;
 
 class Build is Panda::Builder {
     method build($workdir) {
-        if !library-exists('libsamplerate') {
+        if !library-exists('samplerate', v0) {
             say "Won't build because no libsamplerate";
             die "You need to have libsamplerate installed";
         }
